aboutsummaryrefslogtreecommitdiff
path: root/ci
diff options
context:
space:
mode:
authorMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2024-01-02 12:30:44 +0100
committerMarcoFalke <*~=`'#}+{/-|&$^_@721217.xyz>2024-04-27 14:54:00 +0200
commitfa1964c5b80ee28b0e06abdbd9a26e8e8c6f5acd (patch)
treea95e61d0ba06255676ec48c9bfc4ecaf2f011957 /ci
parent7973a670915632b75a6aa16f24f98b936865c48f (diff)
downloadbitcoin-fa1964c5b80ee28b0e06abdbd9a26e8e8c6f5acd.tar.xz
build: Bump clang minimum supported version to 15
Diffstat (limited to 'ci')
-rwxr-xr-xci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh b/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
index 6f0b9cc285..6425120afb 100755
--- a/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
+++ b/ci/test/00_setup_env_native_nowallet_libbitcoinkernel.sh
@@ -8,8 +8,8 @@ export LC_ALL=C.UTF-8
export CONTAINER_NAME=ci_native_nowallet_libbitcoinkernel
export CI_IMAGE_NAME_TAG="docker.io/ubuntu:22.04"
-# Use minimum supported python3.9 (or best-effort 3.10) and clang-14, see doc/dependencies.md
-export PACKAGES="python3-zmq clang-14 llvm-14 libc++abi-14-dev libc++-14-dev"
-export DEP_OPTS="NO_WALLET=1 CC=clang-14 CXX='clang++-14 -stdlib=libc++'"
+# Use minimum supported python3.9 (or best-effort 3.10) and clang-15, see doc/dependencies.md
+export PACKAGES="python3-zmq clang-15 llvm-15 libc++abi-15-dev libc++-15-dev"
+export DEP_OPTS="NO_WALLET=1 CC=clang-15 CXX='clang++-15 -stdlib=libc++'"
export GOAL="install"
export BITCOIN_CONFIG="--enable-reduce-exports --enable-experimental-util-chainstate --with-experimental-kernel-lib --enable-shared"